pub struct RunReport {
pub errors: usize,
pub warnings: usize,
pub any_success: bool,
pub any_failure: bool,
}Expand description
Summary of what run observed in the clippy stream.
Returned so the caller can choose an exit code that mirrors clippy’s (non-zero when the build failed or at least one error-level diagnostic was reported).
Fields
errors: usizeNumber of unique error-level diagnostics.
warnings: usizeNumber of unique warning-level diagnostics.
any_success: boolAt least one build-finished message reported success: true.
any_failure: boolAt least one build-finished message reported success: false.
Implementations